
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
/// 大小等同于父控件的大小，一般使用Container包起来 例如：
/// Container(
//    width: 300,
//    height: 200,
//    child: LinkVVideoWidget(uid: _userId, isMaster: widget.isMaster),
//  )
/// @pram uid 用户id
/// @pram isMaster 是否是主播，如果是主播，当视图添加到界面上之后，会自动开始视频采集
class LinkVVideoWidget extends StatelessWidget {

  LinkVVideoWidget({this.uid, this.isMaster});

  final String uid;
  final bool isMaster;

  @override
  Widget build(BuildContext context) {
    if (uid == null || uid.length == 0) return Container();
    if (defaultTargetPlatform == TargetPlatform.android) {
      return AndroidView(
        // 在Native中视图的唯一标识，需要与Native侧值相同
        viewType: "surface",
        // 传递给Native侧初始化视图时的参数
        creationParams: <String, dynamic>{"uid": uid, "isMaster": isMaster},
        // 用来编码 creationParams 的形式，可选 [StandardMessageCodec], [JSONMessageCodec], [StringCodec], or [BinaryCodec]
        // 如果存在 creationParams，则该值不能为null
        creationParamsCodec: const StandardMessageCodec(),
      );
    } else if (defaultTargetPlatform == TargetPlatform.iOS) {
      return UiKitView(
        viewType: "surface",
        creationParams: <String, dynamic>{"uid": uid, "isMaster": isMaster},
        creationParamsCodec: const StandardMessageCodec(),
      );
    } else {
      return Text("不支持的平台");
    }
  }
}